[PATCH 1/2] rm: only refresh entries that we may touch
- From
Nguyễn Thái Ngọc Duy <pclouds@gmail.com>
- Date
- Jan 14, 2010, 15:02 UTC
- Message-ID
- <1263481341-28401-2-git-send-email-pclouds@gmail.com>
- In-Reply-To
- <1263481341-28401-1-git-send-email-pclouds@gmail.com>
This gets rid of the whole tree cache refresh. Instead only path that we touch will get refreshed. We may still lstat() more than needed, but it'd be better playing safe.
This potentially reduces a large number of lstat() on big trees. Take gentoo-x86 tree for example, which has roughly 80k files:
Unmodified Git:
$ time git rm --cached skel.ChangeLog rm 'skel.ChangeLog'
real 0m1.323s user 0m0.806s sys 0m0.517s
Modified Git:
$ time git rm --cached skel.ChangeLog rm 'skel.ChangeLog'
real 0m0.903s user 0m0.780s sys 0m0.100s
Signed-off-by: Nguyễn Thái Ngọc Duy <pclouds@gmail.com> --- builtin-rm.c | 2 +- 1 files changed, 1 insertions(+), 1 deletions(-)
diff --git a/builtin-rm.c b/builtin-rm.c index 57975db..4cac3d1 100644 --- a/builtin-rm.c +++ b/builtin-rm.c @@ -169,7 +169,6 @@ int cmd_rm(int argc, const char **argv, const char *prefix) if (read_cache() < 0) die("index file corrupt"); - refresh_cache(REFRESH_QUIET); pathspec = get_pathspec(prefix, argv); seen = NULL; @@ -181,6 +180,7 @@ int cmd_rm(int argc, const char **argv, const char *prefix) struct cache_entry *ce = active_cache[i]; if (!match_pathspec(pathspec, ce->name, ce_namelen(ce), 0, seen)) continue; + refresh_cache_entry(ce, 1); add_list(ce->name); }
-- 1.6.6.181.g5ee6